##Read in the data. This first step shows the path in which the data file sits. I'm importing a tab-delimited file
phenology<-read.delim("~/Documents/ECOL8000/RMBL/barr.txt", header=TRUE)

##I believe that if you are using a PC then you would type in this:
phen<-read.delim("C:\\Users\\jillanderson\\Documents\\ECOL8000\\RMBL\\barr.txt")

##Here, we check the working directory
getwd()

##This sets the working directory
setwd("/Users/jillanderson/Documents/ECOL8000/RMBL")

##This reads in a tab delimited text file
p<-read.delim("barr.txt")

##Here are two methods for reading in csv files
p2<-read.csv("barr.csv")
p3<-read.table("barr.csv", sep=",")


##In R studio, you can import data from the "Environment" pane using the "Import Dataset dropdown" or through the "Tools" menu, followed by the "Import Dataset" submenu

##We will use the phenology data frame. In this step, we are checking to make sure that each data column is read correctly (as a factor or as numeric data)
sapply(phenology,class)

library(metafor)
library(tidyr)


##Exploring relationships for marmots

marmots<-lm(marmot~Year, data=phenology)
summary(marmots)
##For residuals
plot(marmots)

##Here are three methods for plotting the relationship between marmot phenology and year

##1: This code plots the scatterplot, then adds the regression line that we generated above
plot(marmot~Year, data=phenology, xlab="Year", ylab="Marmot emergence (ordinal day)", cex=1.3)
abline(marmots)

##Here, after producing the scatterplot, I've added the coefficients manually
plot(marmot~Year, data=phenology, xlab="Year", ylab="Marmot emergence (ordinal day)", cex=1.3)
curve((1955.5770-0.9217*x), add=T,  from=min(phenology$Year), to=sort(phenology$Year, TRUE)[2])

##Here, we're using ggplot
library(ggplot2)
Marmots =ggplot(phenology, aes(x=Year,y= marmot))+geom_point(size=6.5) +scale_x_continuous("Year")+ scale_y_continuous("Marmot emergence (ordinal day)")
Marmots

Marmots +theme_bw()+ theme_bw()+theme(text = element_text(size=20),axis.line.x = element_line(colour = "black"), axis.line.y = element_line(colour = "black"), panel.border = element_blank(),panel.grid.major =element_blank(), panel.grid.minor=element_blank(),legend.position = "bottom")+geom_smooth(method="lm",  se=FALSE, colour="black", size=1.6)


##You can also evaluate the relationship between marmot phenology and snowmelt data
marmot_snowmelt<-lm(marmot~snowmelt, data=phenology)
summary(marmot_snowmelt)
plot(marmot_snowmelt)
plot(marmot~snowmelt, data=phenology, xlab="Year", ylab="Marmot emergence (ordinal day)", cex=1.3)
abline(marmot_snowmelt)

##What if you expect curvilinearity?
marmot_snowmelt2<-lm(marmot~snowmelt+I(snowmelt^2), data=phenology)

##Marmot phenology vs snowfall

marmot_snowfall<-lm(marmot~Snowfall, data=phenology)
summary(marmot_snowfall)
plot(marmot_snowfall)
plot(marmot~ Snowfall, data=phenology, xlab="Year", ylab="Marmot emergence (ordinal day)", cex=1.3)
abline(marmot_snowfall)


##Marmot phenology vs. snowpack
marmot_snowpack<-lm(marmot~Snowpack, data=phenology)
summary(marmot_snowpack)
plot(marmot_snowpack)
plot(marmot~ Snowpack, data=phenology, xlab="Year", ylab="Marmot emergence (ordinal day)", cex=1.3)
abline(marmot_snowpack)


##What about other species?













##What about if you want to test the hypothesis that all species are altering their phenologies?

##First, you need to rearrange the dataset, so that it is in long form, rather than wide form

library(tidyr)
phenology_long<-gather(phenology, species, phen, marmot:spring_beauty, factor_key=TRUE)
type<-rep(c("m","m","b","b","b","b", "b","b","b","b","b", "b","b","m","b","b", "b","b","b","p", "p", "p"),each=37)
phenology_long<-cbind(phenology_long, type)
phenology_long

##This step is not necessary for analysis. It simply extracts the new dataset and puts it into a file named "phen.txt"
write.table(phenology_long,"phen.txt",sep="\t")
sapply(phenology_long,class)

##Now, we can run the model
overall<-lm(phen~Year*species,data=phenology_long)
anova(overall)
summary(overall)

##We can pull the betas for each species from this model
mod2<-lm(phen~Year*species-1, data= phenology_long)
summary(mod2)
##Extract the coefficient, se, and p-value for each species*year fixed effect

##Note that we don't need to do this for the baseline species - that is why I start with i=2 and not i=1 in this loop

##Make vectors to put this information
Species<-sort(unique(phenology_long$species))
Coefficients<-rep(NA, 22)
SEs<-rep(NA, 22)
Pvalues<-rep(NA, 22)

for (i in 2:length(unique(phenology_long$species))) {
  
  ##Add baseline coefficient with target coefficient
  b<-coef(mod2)[1]+coef(mod2)[i+22]
  ##Add b in vector
  Coefficients[i]<-b
  
  ##Extract species name for target coefficient to use in the next line of code
  spp<-sort(unique(phenology_long$species))[i]
  
  ##Calculate the se for target coefficient from the variance covariance matrix of the model - in this case, for the interaction between year and the target species - Var(Y+S)=Var(Y)+Var(S)+2*cov(Y,S)
  se<-sqrt(vcov(mod2)["Year", "Year"]+vcov(mod2)[paste("Year:species",spp, sep=""), paste("Year:species",spp, sep="")]+2*vcov(mod2)["Year", paste("Year:species", spp, sep="")])
  ##Put SE in vector
  SEs[i]<-se
  
  ##Calculate p-value
  Pvalues[i]<-round(pt(abs(b)/se, df=nrow(phenology_long)-length(coef(mod2)), lower.tail=F)*2, 4)
  
}


##Put everything into a data frame
yeardat<-data.frame(Species, Coefficients, SEs, Pvalues)

##Add the values for the baseline species
yeardat[1,2]<-coef(mod2)[1]
yeardat[1,3]<-summary(mod2)[["coefficients"]][1,2]
yeardat[1,4]<-summary(mod2)[["coefficients"]][1,4]





##Meta-analysis with year. If this were a combination of studies, we might want to run a meta-analysis

##The first step is to create a dataset to look for relationships between snowpack and phenology. To do so, we are going to run a for loop that allows us to extract correlation coefficients between phenology and year for each species

metaYear<-as.data.frame(cbind(c(rep(NA, 22)), c(rep(NA, 22)), c(rep(NA, 22)), as.factor(c(
  "m","m","b","b",
  "b","b", "b","b",
  "b","b","b", "b",
  "b","m","b","b", 
  "b","b","b","p", 
  "p", "p"))))
names(metaYear)<-c("Species", "r", "n", "type")

j=1

for (i in 6:27) {
  
  r<-cor(phenology[,i],phenology[,1],use = "na.or.complete")
  metaYear[j, 1]<-as.character(colnames(phenology)[i])
  metaYear[j, 2]<-r
  metaYear[j, 3]<-sum(!is.na(phenology[,i]))
  if(metaYear[j,4]==2) {metaYear[j, 4]<-"m"}
  if(metaYear[j,4]==1) {metaYear[j, 4]<-"b"}
  if(metaYear[j,4]==3) {metaYear[j, 4]<-"p"}
  
  j=j+1
  
}
##Sorting by taxonomic group (bird, mammal,plant)
metaYear<-with(metaYear, metaYear[order(type),])



##General note: Be careful when using correlation coefficients becasue they need to be in the same units. Here, we have one dataset collected by one person, so it's straightforward. We would also need to be careful of phylogenetic effects if we were doing this exercise for publication.
metaYear$type<-as.factor(metaYear$type)
metaYear$Species<-as.factor(metaYear$Species)


##The first step is to get the metafor package to calculate effect sizes, which are just the correlation coefficients in our example

dat <- escalc(measure="COR", ri=r, ni=n, data=metaYear)

##Next, we run the actual meta-analysis. Can you think of other factors that we should include in the meta-analysis?
meta_year_overall<-rma(yi,vi,data=dat, method="FE")
forest(meta_year_overall)




meta_year<-rma(yi,vi,mods=~type, data=dat, method="FE")
predict(meta_year)
funnel(meta_year)
forest(meta_year)

##Here, we can produce a graph that looks only at birds, mammmals and plants

res.b<-rma(yi,vi, data=dat, subset=type=="b", method="FE")
res.m<-rma(yi,vi, data=dat, subset=type=="m", method="FE")
res.p<-rma(yi,vi, data=dat, subset=type=="p", method="FE")

estimates<-c(coef(res.b), coef(res.m), coef(res.p))
variances<-c(vcov(res.b), vcov(res.m), vcov(res.p))

labels<-c("Birds", "Mammmals", "Plants")

forest(estimates, variances, slab=labels, psize=1, xlab="Correlation")

forest(meta_year_overall, slab=metaYear$Species, psize=1, xlab="Correlation",ylim=c(-4, 25),mlab="Model for all studies")
addpoly(res.b, row=-2, cex=0.75, mlab="Model for Birds")
addpoly(res.m, row=-3, cex=0.75, mlab="Model for Mammals")
addpoly(res.p,  row=-4, cex=0.75, mlab="Model for Plants")


forest(meta_year, order(metaYear$type), slab=metaYear$Species, psize=1, xlab="Correlation coefficient",mlab="Model for all studies")




forest(meta_year, slab=metaYear$Species, order(metaYear$type), xlab="Correlation coefficient", mlab="Model for all studies", psize=1)




##Subsets
birds<-subset(metaYear, type=="b")
mammals<-subset(metaYear, type=="m")
plants<-subset(metaYear, type=="p")

dat_birds <- escalc(measure="COR", ri=r, ni=n, data= birds)
dat_mammals <- escalc(measure="COR", ri=r, ni=n, data= mammals)

meta_year_birds<-rma(yi,vi, data= dat_birds, method="FE")
summary(meta_year_birds)

meta_year_plants<-rma(measure="COR", ri=r, ni=n, data=plants, method="FE")
meta_year_plants

res_birds <- rma(measure="COR", ri=r, ni=n, data=birds, method="FE")
res_birds
predict(res_birds)
funnel(res_birds)
forest(res_birds)

meta_year_mammals<-rma(yi,vi, data=dat_mammals)
summary(meta_year_mammals)




##Meta-analysis with snowmelt timing

metasnow<-as.data.frame(cbind(c(rep(NA, 22)), c(rep(NA, 22)), c(rep(NA, 22)), as.factor(c(
  "m","m","b","b",
  "b","b", "b","b",
  "b","b","b", "b",
  "b","m","b","b", 
  "b","b","b","p", 
  "p", "p"))))
names(metasnow)<-c("Species", "r", "n", "type")



attach(phenology)
j=1

for (i in 6:27) {
  
  r<-cor(phenology[,i],phenology[,5],use = "na.or.complete")
  metasnow[j, 1]<-as.character(colnames(phenology)[i])
  metasnow[j, 2]<-r
  metasnow[j, 3]<-sum(!is.na(phenology[,i]))
  if(metasnow[j,4]==2) {metasnow[j, 4]<-"m"}
  if(metasnow[j,4]==1) {metasnow[j, 4]<-"b"}
  if(metasnow[j,4]==3) {metasnow[j, 4]<-"p"}
  
  j=j+1
  
}
##Sorting by taxonomic group
metasnow <-with(metasnow, metasnow[order(type),])


##Calculating effect sizes
dat_snowmelt <- escalc(measure="COR", ri=r, ni=n, data=metasnow)

##Running the meta-analysis (with a modifier for taxonomic groupd)
meta_snow<-rma(yi,vi,mods=~type, data= dat_snowmelt, method="FE")


forest(meta_snow, order(metasnow$type), slab=metasnow$Species, psize=1, xlab="Correlation coefficient",mlab="Model for all studies")



res.bsnowmelt<-rma(yi,vi, data= dat_snowmelt, subset=type=="b", method="FE")
res.msnowmelt<-rma(yi,vi, data= dat_snowmelt, subset=type=="m", method="FE")
res.psnowmelt<-rma(yi,vi, data= dat_snowmelt, subset=type=="p", method="FE")

estimates_snowmelt<-c(coef(res.bsnowmelt), coef(res.msnowmelt), coef(res.psnowmelt))
variances_snowmelt<-c(vcov(res.bsnowmelt), vcov(res.msnowmelt), vcov(res.psnowmelt))

labels<-c("Birds", "Mammmals", "Plants")

forest(estimates_snowmelt, variances_snowmelt, slab=labels, psize=1, xlab="Correlation")



##Preparing the dataset for looking at relationships between snowfall and phenology

metasnowfall<-as.data.frame(cbind(c(rep(NA, 22)), c(rep(NA, 22)), c(rep(NA, 22)), c(rep(NA, 22))))
names(metasnowfall)<-c("Species", "Beta", "SE", "n")

phenology2<-phenology[-c(1:2),]


j=1

for (i in 6:27) {
  
  mod<-lm(phenology2[,i]~phenology2[,2])
  metasnowfall[j, 1]<-colnames(phenology2)[i]
  metasnowfall[j, 2]<-coef(mod)[2]
  metasnowfall[j, 3]<-coef(summary(mod))[2,2]
  metasnowfall[j, 4]<-sum(!is.na(phenology2[,i]))
  
  j=j+1
  
}


##Preparing the dataset to look for relationships between snowpack and phenology

metasnowpack<-as.data.frame(cbind(c(rep(NA, 22)), c(rep(NA, 22)), c(rep(NA, 22)), c(rep(NA, 22))))
names(metasnowpack)<-c("Species", "Beta", "SE", "n")

phenology2<-phenology[-c(1:2),]


j=1

for (i in 6:27) {
  
  mod<-lm(phenology2[,i]~phenology2[,3])
  metasnowpack[j, 1]<-colnames(phenology2)[i]
  metasnowpack[j, 2]<-coef(mod)[2]
  metasnowpack[j, 3]<-coef(summary(mod))[2,2]
  metasnowpack[j, 4]<-sum(!is.na(phenology2[,i]))
  
  j=j+1
  
}




